@@ -40,11 +40,12 @@ namespace Mono.Zeroconf.Providers.Bonjour
         protected string reply_domain;
         protected string regtype;
         protected uint interface_index;
+        protected AddressProtocol address_protocol;
         
         protected ITxtRecord txt_record;
         protected string fullname;
         protected string hosttarget;
-        protected short port;
+        protected ushort port;
         protected IPHostEntry hostentry;
         
         public Service()
@@ -82,6 +83,11 @@ namespace Mono.Zeroconf.Providers.Bonjour
             set { interface_index = value; }
         }
 
+        public AddressProtocol AddressProtocol {
+            get { return address_protocol; }
+            set { address_protocol = value; }
+        }
+        
         public string Name {
             get { return name; }
             set { name = value; }
@@ -117,13 +123,18 @@ namespace Mono.Zeroconf.Providers.Bonjour
             get { return hostentry; }
         }
 
-        public int NetworkInterface {
-            get { return (int) interface_index; }
+        public uint NetworkInterface {
+            get { return interface_index; }
         }
-        
+                
         public short Port {
-            get { return IPAddress.NetworkToHostOrder(port); }
-            set { port = IPAddress.HostToNetworkOrder(value); }
+            get { return (short)UPort; }
+            set { UPort = (ushort)value; }
+        }
+
+        public ushort UPort {
+            get { return (ushort)IPAddress.NetworkToHostOrder((int)port); }
+            set { port = (ushort)IPAddress.HostToNetworkOrder((int)value); }
         }
     }
 }
